@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use vars qw( $VERSION @EXPORT @EXPORT_OK @ISA $CurrentPackage @IncludeLibs $ScanFileRE );
 
-$VERSION   = '1.12';
+$VERSION   = '1.14';
 @EXPORT    = qw( scan_deps scan_deps_runtime );
 @EXPORT_OK = qw( scan_line scan_chunk add_deps scan_deps_runtime path_to_inc_name );
 
@@ -960,14 +960,20 @@ sub scan_chunk {
             my $diamond = $1;
             return "File/Glob.pm" if $diamond =~ /[*?\[\]{}~\\]/;
         }
+
         return "DBD/$1.pm"    if /\b[Dd][Bb][Ii]:(\w+):/;
-        if (/(?:(:encoding)|\b(?:en|de)code)\(\s*['"]?([-\w]+)/) {
-            my $mod = _find_encoding($2);
-            my @mods = ( 'Encoding.pm' );       # always needed
-            push @mods, 'PerlIO.pm' if $1;      # needed for ":encoding(...)"
+
+        # check for stuff like
+        #   decode("klingon", ...)
+        #   open FH, "<:encoding(klingon)", ...
+        if (my ($io_layer, $encoding) = /(?:(:encoding)|\b(?:en|de)code)\(\s*['"]?([-\w]+)/) {
+            my @mods;
+            my $mod = _find_encoding($encoding);
             push @mods, $mod if $mod;           # "external" Encode module
+            push @mods, qw( PerlIO.pm PerlIO/encoding.pm ) if $io_layer;
             return \@mods;
         }
+
         return $1 if /^(?:do|require)\s+[^"]*"(.*?)"/;
         return $1 if /^(?:do|require)\s+[^']*'(.*?)'/;
         return $1 if /[^\$]\b([\w:]+)->\w/ and $1 ne 'Tk' and $1 ne 'shift';
